@@ -4,9 +4,8 @@
 ## time of creation). The testthat sub-directory now contains a
 ## selected subset of these tests (with some additions) that have been
 ## brought in the testthat format.
+
 library(testthat)
 library(DoseFinding)
-options(testthat.progress.max_fails = 100)
 
-Sys.unsetenv("R_TESTS")
 test_check("DoseFinding")
